@@ -1,6 +1,8 @@
 #gxml will be the api we want to use
 gxml = None
 
+import base
+
 #keep track of the available apis
 available_apis = []
 
@@ -14,30 +16,32 @@ try:
     gxml = minidom.minidom
     #list it as an available api
     Element = minidom.Element
-    tostring = minidom.tostring
+    to_string = minidom.to_string
+    from_string = minidom.from_string
     available_apis.append(['minidom',minidom])
 except ImportError:
     pass
 
 try:
-    import elementtree
-    import elemtree
-    gxml = elemtree.elemtree
-    Element = elemtree.Element
-    tostring = elemtree.tostring
-    available_apis.append(['elementtree',elemtree])
+   import elementtree
+   import elemtree
+   gxml = elemtree.elemtree
+   Element = elemtree.Element
+   to_string = elemtree.to_string
+   from_string = elemtree.from_string
+   available_apis.append(['elementtree',elemtree])
 except ImportError:
-    pass
+   pass
 
 if not gxml:
     raise ImportError("No Supported XML library found!")
 
 def clone(node):
     t = gxml()
-    return t.from_string(tostring(node))
+    return t.from_string(to_string(node))
 
 def preference(pref_list):
-    global gxml, Element, tostring
+    global gxml, Element, to_string
     
     if not isinstance(pref_list,list):
         pref_list = [pref_list]
@@ -48,6 +52,10 @@ def preference(pref_list):
             if preferred == name:
                 return api
     return gxml
+
+def is_element(element):
+    return hasattr(element,'node') or isinstance(element,base.node)    
+
             
 
 
