@@ -8,10 +8,14 @@ class node(object):
         #the gXML object parent
         self.parent = parent
         
+        #the text after the tag? oddness
+        
         #whether or not we've altered the child_nodes, needs to be marked
         #for proper operation, should be true on instantiation
         self._child_nodes_changed = True
-        
+
+    def __len__(self):
+        return len(self.child_nodes)
         
     def __iter__(self):
         return self.child_nodes.__iter__()
@@ -28,4 +32,3 @@ class node(object):
     def __ne__(self,other):
         """Test if two nodes are not equal."""
         return not self == other
-        
